from typing import Any, Dict, List

from filum_utils.clients.common import BaseClient
from filum_utils.clients.knowledge_base.enums import KBDocumentStatusEnum
from filum_utils.clients.knowledge_base.types import UpsertDocumentDataType
from filum_utils.config import config


class KnowledgeBaseClient(BaseClient):
    def __init__(self, organization_id: str):
        super().__init__(
            base_url=config.KNOWLEDGE_BASE_SERVICE_URL,
            username=config.KNOWLEDGE_BASE_SERVICE_USERNAME,
            password=config.KNOWLEDGE_BASE_SERVICE_PASSWORD,
        )
        self._organization_id = organization_id

    def upsert_documents(
        self, documents: List[UpsertDocumentDataType]
    ) -> Dict[str, Any]:
        return self._request(
            method="PUT",
            endpoint="/documents/from-records",
            params={"organization_id": self._organization_id},
            data={"documents": documents},
        )

    def delete_document(self, document_id: str):
        return self._request(
            method="DELETE",
            endpoint=f"/documents/{document_id}",
            params={"organization_id": self._organization_id},
        )

    def update_document_status(
        self, document_id: str, new_status: KBDocumentStatusEnum
    ):
        return self._request(
            method="PUT",
            endpoint=f"/documents/{document_id}",
            params={"organization_id": self._organization_id},
            data={"status": new_status},
        )



from tenacity import retry

from filum_utils.clients.contact_center.common import _RETRY_PARAMS, ContactCenterClient
from filum_utils.clients.contact_center.types import (
    KBDocumentType,
    UpdateDocumentEmbeddingType,
)


class DocumentClient(ContactCenterClient):
    @retry(**_RETRY_PARAMS)
    def get_kb_document(self, organization_id: str, document_id: str) -> KBDocumentType:
        return self._request(
            endpoint=f"/internal/documents/{document_id}",
            method="GET",
            params={"organizationId": organization_id},
        )

    @retry(**_RETRY_PARAMS)
    def update_document_embedding(
        self,
        document_id: str,
        document_embedding: UpdateDocumentEmbeddingType,
    ):
        self._request(
            endpoint=f"/internal/documents/{document_id}/embedding",
            method="PUT",
            data=document_embedding,
        )
